Resctrl selftests refer to "bandwidth" currently in two other forms in
the code ("B/W" and "band width").

Use "bandwidth" consistently everywhere. While at it, fix also one
"over flow" -> "overflow" on a line that is touched by the change.

Suggested-by: Reinette Chatre <reinette.cha...@intel.com>
Signed-off-by: Ilpo Järvinen <ilpo.jarvi...@linux.intel.com>
---

v3:
- New patch
---
 tools/testing/selftests/resctrl/resctrl_val.c | 14 +++++++-------
 tools/testing/selftests/resctrl/resctrlfs.c   |  2 +-
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/tools/testing/selftests/resctrl/resctrlfs.c 
b/tools/testing/selftests/resctrl/resctrlfs.c
index 1cade75176eb..9b86f826a40c 100644
--- a/tools/testing/selftests/resctrl/resctrlfs.c
+++ b/tools/testing/selftests/resctrl/resctrlfs.c
@@ -850,7 +850,7 @@ int validate_bw_report_request(char *bw_report)
        if (strcmp(bw_report, "total") == 0)
                return 0;
 
-       fprintf(stderr, "Requested iMC B/W report type unavailable\n");
+       fprintf(stderr, "Requested iMC bandwidth report type unavailable\n");
 
        return -1;
 }
diff --git a/tools/testing/selftests/resctrl/resctrl_val.c 
b/tools/testing/selftests/resctrl/resctrl_val.c
index bd5a1cbb8a21..126a9cad588b 100644
--- a/tools/testing/selftests/resctrl/resctrl_val.c
+++ b/tools/testing/selftests/resctrl/resctrl_val.c
@@ -361,11 +361,11 @@ static void do_imc_mem_bw_test(void)
 }
 
 /*
  * get_mem_bw_imc - Memory band width as reported by iMC counters
  * @bw_report: Bandwidth report type (reads, writes)
  *
  * Memory B/W utilized by a process on a socket can be calculated using
  * iMC counters. Perf events are used to read these counters.
  *
  * Return: = 0 on success. < 0 on failure.
  */
@@ -379,7 +379,7 @@ static int get_mem_bw_imc(char *bw_report, float *bw_imc)
 
        /*
         * Get results which are stored in struct type imc_counter_config
         * Take over flow into consideration before calculating total b/w
         */
        for (imc = 0; imc < imcs; imc++) {
                struct imc_counter_config *r =
@@ -389,13 +389,13 @@ static int get_mem_bw_imc(char *bw_report, float *bw_imc)
 
                if (read(r->fd, &r->return_value,
                         sizeof(struct membw_read_format)) == -1) {
-                       ksft_perror("Couldn't get read b/w through iMC");
+                       ksft_perror("Couldn't get read bandwidth through iMC");
                        goto close_fds;
                }
 
                if (read(w->fd, &w->return_value,
                         sizeof(struct membw_read_format)) == -1) {
-                       ksft_perror("Couldn't get write bw through iMC");
+                       ksft_perror("Couldn't get write bandwidth through iMC");
                        goto close_fds;
                }
 
@@ -498,7 +498,7 @@ static FILE *open_mem_bw_resctrl(const char *mbm_bw_file)
 
        fp = fopen(mbm_bw_file, "r");
        if (!fp)
-               ksft_perror("Failed to open total bw file");
+               ksft_perror("Failed to open total memory bandwidth file");
 
        return fp;
 }
@@ -361,11 +361,11 @@ static void do_imc_mem_bw_test(void)
 
 /*
- * get_mem_bw_imc - Memory band width as reported by iMC counters
+ * get_mem_bw_imc - Memory bandwidth as reported by iMC counters
  * @bw_report: Bandwidth report type (reads, writes)
  *
@@ -361,11 +361,11 @@ static void do_imc_mem_bw_test(void)
  * @bw_report: Bandwidth report type (reads, writes)
  *
- * Memory B/W utilized by a process on a socket can be calculated using
- * iMC counters. Perf events are used to read these counters.
+ * Memory bandwidth utilized by a process on a socket can be calculated
+ * using iMC counters. Perf events are used to read these counters.
  *
  * Return: = 0 on success. < 0 on failure.
@@ -379,7 +379,7 @@ static int get_mem_bw_imc(char *bw_report, float *bw_imc)
        /*
         * Get results which are stored in struct type imc_counter_config
-        * Take over flow into consideration before calculating total b/w
+        * Take overflow into consideration before calculating total bandwidth.
         */
        for (imc = 0; imc < imcs; imc++) {
-- 
2.39.2


Reply via email to